@@ -1,18 +1,26 @@
 #imports
 import os
 import time
-from ciphers import *
+import  extra_Encodings_pkg.ciphers
+from  extra_Encodings_pkg.ciphers import *
+import  extra_Encodings_pkg.encodingsGui
 #functions to encode and decode
 def encodeto():
     entype = input("Which encoding?")
     if entype.upper() == "ichor".upper():
         obj = input("Encode:")
         for character in obj:
-            encode = ichorEn[character]
+            encode = ichor[character]
             if character == obj[-1]:
                 print(encode,end="\n")
             else:
                 print(encode,end=" ")
+    if entype.upper() == "GEN2":
+        Gen2Code(input('Encode:'))
+    if entype.upper() == 'LTF64':
+        LTF64Code(input('Encode:'))
+    if entype.upper() == 'GTX2':
+        GTX2Code(input('Decode '))
 
 def decodeto():
     detype = input("Which decoding?")
@@ -21,12 +29,18 @@ def decodeto():
         objspce = obj.count(" ") + 1
         obj = obj.split(" ")
         for r in range(objspce):
-            de = obj[r]
-            decode = ichorDe[de]
+            de = int(obj[r])
+            decode = ichor.rev_dict[de]
             if de == obj[-1]:
                 print(decode,end="\n")
             else:
                 print(decode,end="")
+    if detype.upper() == "GEN2":
+        Gen2Code(input('Decode:'))
+    if detype.upper() == 'LTF64':
+        LTF64Code(input('Decode:'))
+    if detype.upper() == 'GTX2':
+        GTX2Code(input('Decode '))
             
 def clear():
     ostype = os.name
@@ -43,7 +57,7 @@ def coder():
     x = ""
     clear()
     while x != "exit".upper():
-        x = input("Encode, Decode, Clear, Credits, or exit?:")
+        x = input("\nEncode, Decode, Clear, Credits,GUI, or exit?:")
         x = x.upper()
         if x == "encode".upper():
             encodeto()
@@ -54,5 +68,7 @@ def coder():
             time.sleep(1)
         if x == "clear".upper():
             clear()
+        if x == "GUI".upper():
+            encodingsGui.startGUI()
 if __name__ == "__main__":
     coder()
